@@ -89,8 +89,8 @@ cleanup_object_storage (void *unused)
 }
 
 static gchar* 
-parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique, 
-                     GkrParsedType type, const gchar *label, guint failures,
+parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrid unique, 
+                     GQuark type, const gchar *label, guint failures,
                      ParseContext *ctx)
 {
  	GkrPkObjectStoragePrivate *pv = GKR_PK_OBJECT_STORAGE_GET_PRIVATE (ctx->storage);
@@ -131,8 +131,8 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 	 */
 	stype = gkr_pk_index_get_string_full (loc, unique, "parsed-type");
 	if (stype) {
-		if (type == GKR_PARSED_UNKNOWN)
-			type = gkr_pkix_parsed_type_from_string (stype);
+		if (!type && stype[0])
+			type = g_quark_from_string (stype);
 		have_indexed = TRUE;
 		g_free (stype);
 	}
@@ -148,7 +148,7 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 	custom_label = NULL;
 	
 	/* We have no idea what kind of data it is, poor user */
-	if (type == GKR_PARSED_UNKNOWN) {
+	if (!type) {
 		display_type = NULL;
 		title = g_strdup (_("Unlock"));
 		primary = g_strdup (_("Enter password to unlock"));
@@ -158,10 +158,19 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 		/* 
 		 * TRANSLATORS: 
 	 	 *  display_type will be the type of the object like 'certificate' or 'key'
-	 	 *  details will the name of the object to unlock.
 	 	 */
 		display_type = gkr_pkix_parsed_type_to_display (type);
+
+		/* 
+		 * TRANSLATORS: 
+	 	 *  display_type will be the type of the object like 'certificate' or 'key'
+	 	 */
 		title = g_strdup_printf (_("Unlock %s"), display_type);
+
+		/* 
+		 * TRANSLATORS: 
+	 	 *  display_type will be the type of the object like 'certificate' or 'key'
+	 	 */
 		primary = g_strdup_printf (_("Enter password for the %s to unlock"), display_type);
 	}
 	
@@ -170,19 +179,39 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 	
 	/* When we've already indexed this data */
 	if (have_indexed) {
-		if (display_type)
+		if (display_type) {
+			/* 
+			 * TRANSLATORS: 
+	 		 *  display_type will be the type of the object like 'certificate' or 'key'
+		 	 *  label is replaced with the name of the locked object.
+		 	 */
 			secondary = g_strdup_printf (_("An application wants access to the %s '%s', but it is locked"), 
 			                             display_type, label);
-		else
+		} else {
+			/* 
+			 * TRANSLATORS: 
+	 		 *  label is replaced with the name of the locked object.
+		 	 */
 			secondary = g_strdup_printf (_("An application wants access to '%s', but it is locked"), label);
+		}
 			
 	/* Never before seen this data */ 
 	} else {
-		if (display_type)
+		if (display_type) {
+			/* 
+			 * TRANSLATORS: 
+	 		 *  display_type will be the type of the object like 'certificate' or 'key'
+		 	 *  label is replaced with the name of the locked object.
+		 	 */
 			secondary = g_strdup_printf(_("The system wants to import the %s '%s', but it is locked."),
 			                            display_type, label);
-		else
+		} else {
+			/* 
+			 * TRANSLATORS: 
+	 		 *  label is replaced with the name of the locked object.
+		 	 */			
 			secondary = g_strdup_printf(_("The system wants to import '%s', but it is locked."), label);
+		}
 	}
 	
 	ask = gkr_ask_request_new (title, primary, GKR_ASK_REQUEST_PROMPT_PASSWORD);
@@ -194,6 +223,10 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 	g_free (secondary);
 		
 	if (gkr_keyring_login_is_usable ()) {
+		/* 
+		 * TRANSLATORS: 
+ 		 *  display_type will be the type of the object like 'certificate' or 'key'
+		 */
 		check = g_strdup_printf (_("Automatically unlock this %s when I log in."), display_type);
 		gkr_ask_request_set_check_option (ask, check);
 		g_free (check);
@@ -206,6 +239,10 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 	} else {
 		ret = gkr_secure_strdup (ask->typed_password);
 		if (ask->checked) {
+			/* 
+			 * TRANSLATORS: 
+		 	 *  label is the name of the object to unlock.
+		 	 */
 			display_name =  g_strdup_printf (_("Unlock password for %s"), label);
 			gkr_keyring_login_attach_secret (GNOME_KEYRING_ITEM_ENCRYPTION_KEY_PASSWORD,
 			                                 display_name, ret,
@@ -213,7 +250,7 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrunique unique,
 		} 
 		
 		/* Track that we prompted for this */
-		g_hash_table_insert (ctx->types_by_unique, gkr_unique_dup (unique), 
+		g_hash_table_insert (ctx->types_by_unique, gkr_id_dup (unique), 
 		                     GUINT_TO_POINTER (type));
 	}	
 		
@@ -312,7 +349,7 @@ remove_object (GkrPkObjectStorage *storage, GkrPkObject *object)
 
 static GkrPkObject*
 prepare_object (GkrPkObjectStorage *storage, GQuark location, 
-                gkrconstunique unique, GkrParsedType type)
+                gkrconstid unique, GQuark type)
 {
 	GkrPkObjectStoragePrivate *pv = GKR_PK_OBJECT_STORAGE_GET_PRIVATE (storage);
 	GkrPkObjectManager *manager;
@@ -329,17 +366,14 @@ prepare_object (GkrPkObjectStorage *storage, GQuark location,
 		return object;
 	} 
 	
-	switch (type) {
-	case GKR_PARSED_PRIVATE_KEY:
+	if (type == GKR_PKIX_PRIVATE_KEY) 
 		gtype = GKR_TYPE_PK_PRIVKEY;
-		break;
-	case GKR_PARSED_CERTIFICATE:
+	else if (type == GKR_PKIX_PUBLIC_KEY) 
+		gtype = GKR_TYPE_PK_PUBKEY;
+	else if (type == GKR_PKIX_CERTIFICATE)
 		gtype = GKR_TYPE_PK_CERT;
-		break;
-	default:
+	else 
 		g_return_val_if_reached (NULL);
-		break;
-	}
 	
 	object = g_object_new (gtype, "manager", manager, "location", location, 
 	                       "unique", unique, NULL);
@@ -354,22 +388,22 @@ g_printerr ("parsed %s at %s\n", G_OBJECT_TYPE_NAME (object), g_quark_to_string
 }
 
 static void 
-parser_parsed_partial (GkrPkixParser *parser, GQuark location, gkrunique unique,
-                       GkrParsedType type, ParseContext *ctx)
+parser_parsed_partial (GkrPkixParser *parser, GQuark location, gkrid unique,
+                       GQuark type, ParseContext *ctx)
 {
  	GkrPkObjectStoragePrivate *pv = GKR_PK_OBJECT_STORAGE_GET_PRIVATE (ctx->storage);
  	GkrPkObject *object;
  	gchar *stype;
  	
 	/* If we don't know the type then look it up */
-	if (type == GKR_PARSED_UNKNOWN) {
+	if (!type) {
 		stype = gkr_pk_index_get_string_full (location, unique, "parsed-type");
-		if (stype)
-			type = gkr_pkix_parsed_type_from_string (stype);
+		if (stype && stype[0])
+			type = g_quark_from_string (stype);
 		g_free (stype);
 	}
 	
-	if (type != GKR_PARSED_UNKNOWN) { 
+	if (type) { 
 	 	object = prepare_object (ctx->storage, location, unique, type);
  		g_return_if_fail (object != NULL);
  	
@@ -381,18 +415,18 @@ parser_parsed_partial (GkrPkixParser *parser, GQuark location, gkrunique unique,
 	}
 	
 	/* Track the type for this unique */
-	g_hash_table_insert (ctx->types_by_unique, gkr_unique_dup (unique), 
+	g_hash_table_insert (ctx->types_by_unique, gkr_id_dup (unique), 
 		             GUINT_TO_POINTER (type));
 }
 
 static void
-parser_parsed_sexp (GkrPkixParser *parser, GQuark location, gkrunique unique,
-	            GkrParsedType type, gcry_sexp_t sexp, ParseContext *ctx)
+parser_parsed_sexp (GkrPkixParser *parser, GQuark location, gkrid unique,
+	                GQuark type, gcry_sexp_t sexp, ParseContext *ctx)
 {
  	GkrPkObjectStoragePrivate *pv = GKR_PK_OBJECT_STORAGE_GET_PRIVATE (ctx->storage);
  	GkrPkObject *object;
  	
- 	g_return_if_fail (type != GKR_PARSED_UNKNOWN);
+ 	g_return_if_fail (type != 0);
  	
  	object = prepare_object (ctx->storage, location, unique, type);
  	g_return_if_fail (object != NULL);
@@ -404,7 +438,7 @@ parser_parsed_sexp (GkrPkixParser *parser, GQuark location, gkrunique unique,
 	g_hash_table_remove (ctx->checks, object);
 		
 	/* Track the type for this unique */
-	g_hash_table_insert (ctx->types_by_unique, gkr_unique_dup (unique), 
+	g_hash_table_insert (ctx->types_by_unique, gkr_id_dup (unique), 
 		             GUINT_TO_POINTER (type));
 	
 	/* Setup the sexp, probably a key on this object */
@@ -412,13 +446,13 @@ parser_parsed_sexp (GkrPkixParser *parser, GQuark location, gkrunique unique,
 }
 
 static void
-parser_parsed_asn1 (GkrPkixParser *parser, GQuark location, gkrconstunique unique, 
-                    GkrParsedType type, ASN1_TYPE asn1, ParseContext *ctx)
+parser_parsed_asn1 (GkrPkixParser *parser, GQuark location, gkrconstid unique, 
+                    GQuark type, ASN1_TYPE asn1, ParseContext *ctx)
 {
  	GkrPkObjectStoragePrivate *pv = GKR_PK_OBJECT_STORAGE_GET_PRIVATE (ctx->storage);
 	GkrPkObject *object;
 	
- 	g_return_if_fail (type != GKR_PARSED_UNKNOWN);
+ 	g_return_if_fail (type != 0);
  	
 	object = prepare_object (ctx->storage, location, unique, type);
 	g_return_if_fail (object != NULL);
@@ -430,7 +464,7 @@ parser_parsed_asn1 (GkrPkixParser *parser, GQuark location, gkrconstunique uniqu
 	g_hash_table_remove (ctx->checks, object);
 	
 	/* Track the type for this unique */
-	g_hash_table_insert (ctx->types_by_unique, gkr_unique_dup (unique), 
+	g_hash_table_insert (ctx->types_by_unique, gkr_id_dup (unique), 
 		             GUINT_TO_POINTER (type));
 
 	/* Setup the asn1, probably a certificate on this object */
@@ -446,14 +480,17 @@ remove_each_object (GkrPkObject *object, gpointer unused, GkrPkObjectStorage *st
 }
 
 static void
-index_each_unique (gkrunique unique, gpointer value, gpointer data)
+index_each_unique (gkrid unique, gpointer value, gpointer data)
 {
 	GQuark location = GPOINTER_TO_UINT (data);
-	GkrParsedType type = GPOINTER_TO_UINT (value);
+	GQuark type = GPOINTER_TO_UINT (value);
 	
+	if (!type)
+		return;
+
 	/* Stash away the parsed type, in case we need it when prompting for a password */
 	gkr_pk_index_set_string_full (location, unique, "parsed-type", 
-	                              gkr_pkix_parsed_type_to_string (type));
+	                              g_quark_to_string (type));
 }
 
 static gboolean
@@ -461,7 +498,7 @@ load_objects_at_location (GkrPkObjectStorage *storage, GQuark loc, GError **err)
 {
  	GkrPkObjectStoragePrivate *pv = GKR_PK_OBJECT_STORAGE_GET_PRIVATE (storage);
  	GkrPkixParser *parser;
- 	GkrParseResult ret;
+ 	GkrPkixResult ret;
  	GkrPkObject *object;
 	ParseContext ctx;
 	GArray *objs;
@@ -474,8 +511,8 @@ load_objects_at_location (GkrPkObjectStorage *storage, GQuark loc, GError **err)
 	ctx.storage = storage;
 	ctx.checks = g_hash_table_new_full (g_direct_hash, g_direct_equal, 
 	                                    g_object_unref, NULL);
-	ctx.types_by_unique = g_hash_table_new_full (gkr_unique_hash, gkr_unique_equals, 
-	                                             gkr_unique_free, NULL);
+	ctx.types_by_unique = g_hash_table_new_full (gkr_id_hash, gkr_id_equals, 
+	                                             gkr_id_free, NULL);
 
 	/* Create a table of what is at the location */
 	k = GUINT_TO_POINTER (loc);
@@ -570,7 +607,7 @@ gkr_pk_object_storage_init (GkrPkObjectStorage *storage)
  	
  	pv->objects = g_hash_table_new_full (g_direct_hash, g_direct_equal, g_object_unref, NULL);
  	pv->objects_by_location = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, free_array);
-	pv->specific_load_requests = g_hash_table_new_full (gkr_unique_hash, gkr_unique_equals, gkr_unique_free, NULL);
+	pv->specific_load_requests = g_hash_table_new_full (gkr_id_hash, gkr_id_equals, gkr_id_free, NULL);
 	
 	for (i = 0; i < G_N_ELEMENTS (gkr_pk_places); ++i) {
 		place = &gkr_pk_places[i];
@@ -694,7 +731,7 @@ gkr_pk_object_storage_load_complete (GkrPkObjectStorage *storage, GkrPkObject *o
 
 	
 	/* Make note of the specific load request */
-	g_hash_table_replace (pv->specific_load_requests, gkr_unique_dup (obj->unique), NO_VALUE); 
+	g_hash_table_replace (pv->specific_load_requests, gkr_id_dup (obj->unique), NO_VALUE); 
 	ret = load_objects_at_location (storage, obj->location, err);
 
 	if (!ret) 
